@@ -431,7 +431,7 @@ class SpectrumList_MSnImpl : public SpectrumList_MSn
           {
             const pair<int, double>& chargeMass = chargeMassPairs.at(i);
             precursor.selectedIons.back().cvParams.push_back(CVParam(MS_charge_state, chargeMass.first));
-            precursor.selectedIons.back().cvParams.push_back(CVParam(MS_accurate_mass_OBSOLETE, chargeMass.second));
+            precursor.selectedIons.back().userParams.emplace_back("accurate mass", toString(chargeMass.second), "xsd:double");
             precursor.selectedIons.back().set(MS_selected_ion_m_z, 
                                               calculateMassOverCharge(chargeMass.second, chargeMass.first,
                                                                       1), // this is a singly charged mass
@@ -523,7 +523,7 @@ class SpectrumList_MSnImpl : public SpectrumList_MSn
           
               // store each charge and accurate mass as a separate selected ion
               precursor.selectedIons.back().cvParams.push_back(CVParam(MS_charge_state, eCharge));
-              precursor.selectedIons.back().cvParams.push_back(CVParam(MS_accurate_mass_OBSOLETE, eMass));
+              precursor.selectedIons.back().userParams.emplace_back("accurate mass", toString(eMass), "xsd:double");
               precursor.selectedIons.back().set(MS_selected_ion_m_z, calculateMassOverCharge(eMass, eCharge, 1), MS_m_z);
               precursor.selectedIons.push_back(SelectedIon());
             }
